package edu.sc.seis.TauP;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

public abstract class SimpleSeismicPhase implements SeismicPhase {


    /**
     * Calculates arrivals for this phase, but only for the exact distance in radians. This does not check multiple
     * laps nor going the long way around.
     *  */
    public abstract List<Arrival> calcTimeExactDistance(double searchDist);

    public List<ArrivalPathSegment> calcSegmentPaths(Arrival currArrival) throws NoArrivalException {
        return calcSegmentPaths(currArrival, null, 0);
    }

    /**
     * Calc path with a starting time-distance possibly not zero. Used when this simple phase
     * is the outbound phase of a scattered phase and so the path needs to start at the
     * scatterer distance.
     *
     * @param currArrival
     * @param prevEnd
     * @return
     */
    public List<ArrivalPathSegment> calcSegmentPaths(Arrival currArrival, TimeDist prevEnd, int prevIdx) throws NoArrivalException {
        int idx = prevIdx+1;
        List<ArrivalPathSegment> segmentPaths = new ArrayList<>();
        int numSegments = currArrival.listPhaseSegments().size();
        for (SeismicPhaseSegment seg : currArrival.listPhaseSegments()) {
            ArrivalPathSegment segPath = seg.calcPathTimeDist(currArrival, prevEnd, idx++, prevIdx+ numSegments);

            if (segPath.path.isEmpty()) {
                continue;
            }
            segmentPaths.add(segPath);
            prevEnd = segPath.getPathEnd();
        }
        return ArrivalPathSegment.adjustPath(segmentPaths, currArrival);
    }

    public abstract SimpleSeismicPhase interpolateSimplePhase(double maxDeltaDeg);

    @Override
    public String describeJson() {
        String Q = ""+'"';
        String COMMA = ",";
        String QCOMMA = Q+COMMA;
        String COLON = ": "; // plus space
        String S = "  ";
        String QC = Q+COLON;
        String QCQ = QC+Q;
        String SS = S+S;
        String SQ = S+Q;
        String SSQ = S+SQ;
        String SSSQ = S+SSQ;
        StringWriter sw = new StringWriter();
        PrintWriter out = new PrintWriter(sw);
        out.println("{");
        out.println(SQ+"name"+QCQ+getName()+QCOMMA);
        out.println(SQ+"puristname"+QCQ+getPuristName()+QCOMMA);
        if (isFail()) {
            out.println(SQ+"fail"+QCQ+failReason()+QCOMMA);
        }
        String baseDesc = SeismicPhase.baseDescribeJSON(this);
        if (!baseDesc.isEmpty()) {
            out.println(baseDesc+",");
        }
        out.println(SeismicPhase.segmentDescribeJSON(this));
        out.print("}");
        return sw.toString();
    }
}
